@@ -25,9 +25,6 @@ Test::Prereq - check if Makefile.PL has the right pre-requisites
 	plan skip_all => "Test::Prereq required to test dependencies" if $@;
 	prereq_ok();
 
-	# specify a perl version, test name, or module names to skip
-	prereq_ok( $version, $name, \@skip );
-
 	# if you use Module::Build
 	use Test::More;
 	eval "use Test::Prereq::Build";
@@ -74,7 +71,7 @@ about this.
 use vars qw($VERSION $EXCLUDE_CPANPLUS @EXPORT @prereqs);
 
 
-$VERSION = '2.002';
+$VERSION = '2.004';
 
 @EXPORT = qw( prereq_ok );
 
@@ -108,35 +105,31 @@ no warnings;
 
 =over 4
 
-=item prereq_ok( [ VERSION, [ NAME [, SKIP_ARRAY] ] ] )
+=item prereq_ok( [ NAME [, SKIP_ARRAY] ] )
 
 Tests F<Makefile.PL> to ensure all non-core module dependencies are in
 C<PREREQ_PM>. If you haven't set a testing plan already,
 C<prereq_ok()> creates a plan of one test.
 
-If you don't specify a version, C<prereq_ok> assumes you want to compare
-the list of prerequisite modules to the version of perl running the
-test.
-
 Valid versions come from C<Module::CoreList> (which uses C<$]>).
 
 	#!/usr/bin/perl
 	use Module::CoreList;
 	print map "$_\n", sort keys %Module::CoreList::version;
 
-C<prereq_ok> attempts to remove modules found in F<lib/> and
-libraries found in F<t/> from the reported prerequisites.
+C<prereq_ok> attempts to remove modules found in F<lib/> and libraries
+found in F<t/> from the reported prerequisites.
 
-The optional third argument is an array reference to a list
-of names that C<prereq_ok> should ignore. You might want to use
-this if your tests do funny things with C<require>.
+The optional third argument is an array reference to a list of names
+that C<prereq_ok> should ignore. You might want to use this if your
+tests do funny things with C<require>.
 
 Versions prior to 1.038 would use CPAN.pm to virtually include
-prerequisites in distributions that you declared explicitly. This isn't
-really a good idea. Some modules have moved to different distributions,
-so you should just specify all the modules that you use instead of relying
-on a particular distribution to provide them. Not only that, expanding
-distributions with CPAN.pm takes forever.
+prerequisites in distributions that you declared explicitly. This
+isn't really a good idea. Some modules have moved to different
+distributions, so you should just specify all the modules that you use
+instead of relying on a particular distribution to provide them. Not
+only that, expanding distributions with CPAN.pm takes forever.
 
 If you want the old behavior, set the C<TEST_PREREQ_EXPAND_WITH_CPAN>
 environment variable to a true value.
@@ -348,8 +341,11 @@ sub _get_from_file {
 				();
 			} $modules->@*;
 
-	my @modules = map { $_->module } $modules->@*;
-	push @modules, @imports;
+	my @modules =
+		grep { state %Seen; ! $Seen{$_}++ } (
+			@imports,
+			map { $_->module } $modules->@*
+			);
 
 	return \@modules;
 	}
@@ -380,11 +376,11 @@ Andy Lester, Slavin Rezić, Randal Schwartz, Iain Truskett, Dylan Martin
 
 =head1 AUTHOR
 
-brian d foy, C<< <bdfoy@cpan.org> >>
+brian d foy, C<< <briandfoy@pobox.com> >>
 
 =head1 COPYRIGHT and LICENSE
 
-Copyright © 2002-2016, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright © 2002-2025, brian d foy <briandfoy@pobox.com>. All rights reserved.
 This software is available under the Artistic License 2.
 
 =cut
