@@ -20,7 +20,7 @@ Test::Prereq::Build - test prerequisites in Module::Build scripts
 
 =cut
 
-$VERSION = '2.001_002';
+$VERSION = '2.004';
 
 use Module::Build;
 
@@ -52,11 +52,11 @@ some methods to do nothing.
 
 =head1 AUTHOR
 
-brian d foy, C<< <bdfoy@cpan.org> >>
+brian d foy, C<< <briandfoy@pobox.com> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2002-2015, brian d foy <bdfoy@cpan.org>. All rights reserved.
+Copyright © 2002-2025, brian d foy <briandfoy@pobox.com>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
@@ -92,6 +92,7 @@ sub Module::Build::new {
 	my @requires = sort grep $_ ne 'perl', (
 		keys %{ $hash{requires} },
 		keys %{ $hash{build_requires} },
+		keys %{ $hash{test_requires} },
 		keys %{ $hash{configure_requires} },
 		keys %{ $hash{recommends} },
 		);
